<?xml version="1.0" encoding="UTF-8"?>
<!-- via xpath-default-namespace wird der TEI-Namespace standardmäßig angenommen udn muss nich tmitnotiert werden -->
<!--ISt das stylesheet via transformatiosnszenario verbunden, erkennt der XSL-Prozessor Ihren Quellbaum udn schlägt die richtigen Knoten vor (Elemente, Attribute etc.) -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xs" version="2.0"
    xpath-default-namespace="http://www.tei-c.org/ns/1.0">

    <xsl:template match="/">
        <!-- HTML Baum aufbauen -->
        <html>
            <head>
                <!-- Den Dokumenttitel in den HTML-Head rasuschreiben -->
                <title>
                    <xsl:value-of select="//teiHeader/fileDesc/titleStmt/title"/>
                </title>
            </head>
            <body>
                <!-- Faulenzer-Anweisung -->
                <xsl:apply-templates/>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="teiHeader"/>

    <!-- Überschrift ausgeben -->
    <xsl:template match="//body//head">
        <h1>
            <xsl:value-of select="."/>
        </h1>
    </xsl:template>

    <!-- Einleitungssatz ausgeben -->
    <xsl:template match="body//p">
        <p>
            <xsl:value-of select="."/>
        </p>
    </xsl:template>

    <!-- person/persName|sex|birth|death -->
    <xsl:template match="listPerson">
        <!-- HTML-Liste anlegen -->
        <ol>
            <!-- Sahle Sortierungen -->
            <xsl:for-each select="//listPerson/person[persName/surname/text()]">
                <!-- sortiere erstens nach Geschlecht -->
                <xsl:sort select="sex/@value"/>
                <!-- sortiere zweitens nach Lebensalter absteigend -->
                <xsl:sort select="death/date/@when-iso - birth/date/@when-iso" data-type="number"
                    order="descending"/>
                <li>
                    <!-- Geschlechtsangabe ausgeben -->
                    <xsl:value-of select="sex/@value"/>
                    <xsl:text> - </xsl:text>
                    <!-- Lebensalter berechnen und ausgeben -->
                    <xsl:value-of select="death/date/@when-iso - birth/date/@when-iso"/>
                    <xsl:text> - </xsl:text>
                    <!-- Nachname ausgeben -->
                    <xsl:value-of select="persName/surname"/>
                    <!-- wenn ein Vorname angegeben ist, dann schön ausgeben -->
                    <xsl:if test="persName/forename/text()">
                        <xsl:text>, </xsl:text>
                    </xsl:if>
                    <xsl:value-of select="persName/forename"/>
                    <!-- Lebensdaten schön ausgeben, aber nur dann, wenn sie vorhanden sind -->
                    <xsl:if test="(birth/date/@when-iso) or (death/date/@when-iso)">
                        <xsl:text> (</xsl:text>
                        <xsl:value-of select="birth/date/@when-iso"/>
                        <xsl:text>-</xsl:text>
                        <xsl:value-of select="death/date/@when-iso"/>
                        <xsl:text>)</xsl:text>
                    </xsl:if>
                </li>
            </xsl:for-each>
        </ol>
    </xsl:template>

    <xsl:template match="person"/> 








</xsl:stylesheet>
